#!/usr/bin/env node
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _fs = require("fs");

var _path = require("path");

var _commander = _interopRequireDefault(require("commander"));

var _webpack = _interopRequireDefault(require("webpack"));

var _mkdirp = _interopRequireDefault(require("mkdirp"));

var _loaderUtils = _interopRequireDefault(require("loader-utils"));

var _validateSchema = _interopRequireDefault(require("../lib/validate-schema"));

require("../bootstrap");

var _ = require("..");

var _package = _interopRequireDefault(require("../../package.json"));

(0, _validateSchema.default)();

_commander.default.option('-c, --clean', 'clean dll cache').parse(process.argv);

const context = (0, _.getContext)();

const projectPackage = require((0, _path.resolve)(context, 'package.json'));

const webpackConfigDll = (0, _.pRequire)('config/webpack.dll.babel', _commander.default);
const appConfig = (0, _.pRequire)('config/packing');
const {
  commonChunks,
  path: {
    tmpDll
  }
} = appConfig;

if (Object.keys(commonChunks).length !== 0) {
  const allDependencies = Object.assign(_package.default.dependencies, _package.default.devDependencies, projectPackage.dependencies, projectPackage.devDependencies);
  const dllDeps = {};
  const destDir = (0, _path.resolve)(context, tmpDll);
  const hashFile = `${destDir}/hash.json`;

  if (_commander.default.clean) {
    if ((0, _fs.existsSync)(hashFile)) {
      (0, _fs.unlinkSync)(hashFile);
    }
  }

  Object.keys(commonChunks).forEach(chunkName => {
    commonChunks[chunkName].forEach(d => {
      if (allDependencies[d]) {
        dllDeps[d] = allDependencies[d];
      }
    });
  });

  const newHash = _loaderUtils.default.getHashDigest(JSON.stringify(dllDeps));

  let skip = true;

  if ((0, _fs.existsSync)(hashFile)) {
    const oldHash = require(hashFile).hash;

    console.log('[packing-dll]oldHash:', oldHash);
    console.log('[packing-dll]newHash:', newHash);

    if (oldHash !== newHash) {
      skip = false;
    }
  } else {
    skip = false;
  }

  if (skip) {
    console.log('💛  DllPlugin skipped!');
  } else {
    // 写入newHash
    (0, _webpack.default)(webpackConfigDll, err => {
      if (err) {
        console.log(err);
      } else {
        if (!(0, _fs.existsSync)(destDir)) {
          _mkdirp.default.sync(destDir);
        }

        (0, _fs.writeFileSync)(hashFile, JSON.stringify({
          hash: newHash
        }));
        console.log('💚  DllPlugin executed!');
      }
    });
  }
}