#!/usr/bin/env node

/**
 * serve脚本
 * @author Joe Zhong <zhong.zhi@163.com>
 * @module tools/serve
 */
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _path = require("path");

var _fs = require("fs");

var _util = require("util");

var _express = _interopRequireDefault(require("express"));

var _packingUrlrewrite = _interopRequireDefault(require("packing-urlrewrite"));

require("../bootstrap");

var _ = require("..");

const context = (0, _.getContext)();
const appConfig = (0, _.pRequire)('config/packing', {});
const {
  template: {
    options: {
      engine,
      extension
    }
  },
  rewriteRules,
  path: {
    dist: {
      root: distRoot,
      templates: distTemplates
    },
    mockPages
  },
  port: {
    dist: port
  }
} = appConfig;
let templates = (0, _util.isString)(distTemplates) ? distTemplates : distTemplates.pages;
templates = (0, _path.join)(distRoot, templates);

const parserHtml = ({
  templates: templateRoot
}) => (req, res) => {
  const {
    pathname
  } = req._parsedUrl; // eslint-disable-line

  const file = `${(0, _path.resolve)(context, templateRoot)}${pathname}.html`;

  if ((0, _fs.existsSync)(file)) {
    const output = (0, _fs.readFileSync)(file, {
      encoding: 'utf-8'
    });
    res.end(output);
  } else {
    res.status(404);
  }
};

const app = new _express.default();
app.use(_express.default.static((0, _path.resolve)(context, distRoot)));
app.use((0, _packingUrlrewrite.default)(rewriteRules));

if (engine === 'html') {
  app.use(parserHtml({
    templates
  }));
} else {
  const options = {
    templates,
    // 使用相对路径
    mockData: mockPages,
    rewriteRules,
    extension
  };

  if (engine === 'pug') {
    options.basedir = (0, _path.dirname)((0, _path.resolve)(context, templates));
  }

  app.use(require(`packing-template-${engine}`)(options));
}

app.listen(port, err => {
  if (err) {
    console.error(err);
  } else {
    console.info('==> 🚧  Listening on port %s', port);
  }
});