#!/usr/bin/env node
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _child_process = require("child_process");

var _path = require("path");

var _commander = _interopRequireDefault(require("commander"));

var _webpack = _interopRequireDefault(require("webpack"));

var _express = _interopRequireDefault(require("express"));

var _packingUrlrewrite = _interopRequireDefault(require("packing-urlrewrite"));

var _webpackDevMiddleware = _interopRequireDefault(require("webpack-dev-middleware"));

var _webpackHotMiddleware = _interopRequireDefault(require("webpack-hot-middleware"));

var _cliSpinner = require("cli-spinner");

var _inquirer = _interopRequireDefault(require("inquirer"));

var _ = require("..");

var _validateSchema = _interopRequireDefault(require("../lib/validate-schema"));

require("../bootstrap");

(0, _validateSchema.default)();

_commander.default.option('-c, --clean', 'clean dll cache').option('-d, --no-dll', 'skip dll build').option('-l, --no-listen', 'skip listen app').option('-o, --open', 'open browser').option('-p, --partial', 'partial compile').parse(process.argv);

const context = (0, _.getContext)();
const appConfig = (0, _.pRequire)('config/packing');
const {
  rewriteRules,
  graphql: {
    enabled: graphqlEnabled,
    options: graphqlOptions
  },
  hot: {
    enabled: hotEnabled
  },
  template: {
    enabled: templateEnabled
  },
  commonChunks,
  path: {
    src: {
      root: src
    },
    tmpDll
  },
  port: {
    dev: port
  },
  devMwOptions: {
    writeToDisk
  },
  partialCompile: {
    enabled: partialCompileEnabled,
    whitelist
  }
} = appConfig;
const hasCommonChunks = commonChunks && Object.keys(commonChunks).length > 0;
const parser = __dirname.indexOf('/dist/') === 0 ? 'node' : 'node_modules/.bin/babel-node';
let cmd = `CONTEXT=${context} ${parser} ${__dirname}/packing-dll.js`;

if (_commander.default.dll && hasCommonChunks) {
  // 带上命令参数
  if (_commander.default.clean) {
    cmd = `${cmd} -c`;
  }

  try {
    (0, _child_process.execSync)(cmd, {
      encoding: 'utf-8'
    }); // console.log(stdout);
  } catch (e) {
    console.log(e.stdout);
    process.exit(1);
  }
}

function pack(webpackConfig) {
  const compiler = (0, _webpack.default)(webpackConfig);
  const mwOptions = {
    contentBase: src,
    quiet: false,
    noInfo: false,
    hot: true,
    inline: true,
    lazy: false,
    publicPath: webpackConfig.output.publicPath,
    headers: {
      'Access-Control-Allow-Origin': '*'
    },
    stats: {
      colors: true
    },
    writeToDisk,
    serverSideRender: true
  };
  const dllPath = (0, _path.join)(context, tmpDll);
  const webpackDevMiddlewareInstance = (0, _webpackDevMiddleware.default)(compiler, mwOptions);
  const spinner = new _cliSpinner.Spinner('webpack: bundling.. %s');
  spinner.setSpinnerDelay(100);
  setTimeout(() => {
    spinner.start();
  }, 0);
  webpackDevMiddlewareInstance.waitUntilValid(() => {
    spinner.stop(true);
    const app = new _express.default();
    app.use(_express.default.static(context));
    app.use(_express.default.static(dllPath));
    app.use((0, _packingUrlrewrite.default)(rewriteRules));
    app.use(webpackDevMiddlewareInstance);

    if (hotEnabled) {
      app.use((0, _webpackHotMiddleware.default)(compiler));
    }

    if (templateEnabled) {
      (0, _.middleware)(app, appConfig);
    }

    if (graphqlEnabled) {
      const graphqlMockServer = require('../lib/graphql-mock-server');

      graphqlMockServer(app, graphqlOptions);
    }

    if (_commander.default.listen) {
      app.listen(port, err => {
        if (err) {
          console.error(err);
        } else {
          console.info('==> 🚧  Listening on port %s\n', port);
        }
      });
    } else {
      process.exit(0);
    }
  });
}

const webpackConfig = (0, _.pRequire)('config/webpack.serve.babel', _commander.default, appConfig);

if (_commander.default.partial || partialCompileEnabled) {
  const prompts = [{
    type: 'checkbox',
    name: 'entries',
    message: 'Which pages do you want to compile?',
    choices: Object.keys(webpackConfig.entry).map(key => ({
      name: key,
      value: key
    })),
    default: whitelist,
    validate: input => input.length > 0
  }];

  _inquirer.default.prompt(prompts).then(answers => {
    Object.keys(webpackConfig.entry).filter(key => !answers.entries.includes(key)).forEach(key => delete webpackConfig.entry[key]);
    pack(webpackConfig);
  });
} else {
  // 全量编译
  pack(webpackConfig);
}