"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _path = _interopRequireDefault(require("path"));

var _querystring = require("querystring");

var _util = require("util");

var _webpack = _interopRequireDefault(require("webpack"));

var _openBrowserWebpackPlugin = _interopRequireDefault(require("open-browser-webpack-plugin"));

var _webpackPwaManifest = _interopRequireDefault(require("webpack-pwa-manifest"));

require("../bootstrap");

var _ = require("..");

var _webpackServe = _interopRequireDefault(require("./webpack.serve.loader"));

var _getEntries = _interopRequireDefault(require("../lib/get-entries"));

/**
 * webpack开发环境配置文件
 * @author Joe Zhong <zhong.zhi@163.com>
 * @module config/webpack.serve.babel
 */
const {
  localhost,
  port,
  hot: {
    enabled: hotEnabled,
    options: hotOptions
  },
  template: {
    options: {
      injectManifest
    }
  },
  commonChunks,
  path: {
    src: {
      root: src
    },
    tmpDll,
    entries
  }
} = (0, _.pRequire)('config/packing');
/**
 * 给所有入口js加上HRM的clientjs
 * @param {string|array|object} entry 页面入口列表
 * @return {array}
 */

const pushClientJS = entry => {
  let clientJS = 'webpack-hot-middleware/client';

  if (hotOptions && Object.keys(hotOptions).length > 0) {
    clientJS = `${clientJS}?${(0, _querystring.stringify)(hotOptions)}`;
  }

  let newEntry = entry;

  if ((0, _util.isString)(newEntry)) {
    newEntry = [clientJS, newEntry];
  } else if ((0, _util.isArray)(newEntry)) {
    newEntry.unshift(clientJS);
  } else if ((0, _util.isObject)(newEntry)) {
    Object.keys(newEntry).forEach(key => {
      newEntry[key] = pushClientJS(newEntry[key]);
    });
  }

  return newEntry;
};
/**
 * 生成webpack配置文件
 * @param {object} program 程序进程，可以获取启动参数
 * @param {object} options 特征配置项
 * @return {object}
 */


const webpackConfig = program => {
  const context = (0, _.getContext)();

  const dllPath = _path.default.resolve(context, tmpDll);

  let entry = (0, _getEntries.default)(entries);
  const mode = 'development';
  const output = {
    chunkFilename: '[name].js',
    filename: '[name].js',
    // prd环境静态文件输出地址
    path: context,
    // dev环境下数据流访问地址
    publicPath: '/'
  };
  const resolve = {
    modules: [src, 'node_modules'],
    extensions: ['.tsx', '.jsx', '.ts', '.js']
  };
  const plugins = [];

  if (injectManifest) {
    plugins.push(new _webpackPwaManifest.default({ ...(0, _.requireDefault)(_path.default.resolve(context, 'config/webpack.manifest')),
      ...{
        filename: '[name][ext]'
      }
    }));
  }

  if (hotEnabled) {
    entry = pushClientJS(entry);
    plugins.push(new _webpack.default.HotModuleReplacementPlugin());
  }

  if (program.open) {
    plugins.push(new _openBrowserWebpackPlugin.default({
      url: `http://${localhost}:${port.dev}`
    }));
  } // 从配置文件中获取dll


  if (commonChunks && Object.keys(commonChunks).length > 0) {
    Object.keys(commonChunks).forEach(key => {
      plugins.push(new _webpack.default.DllReferencePlugin({
        context,
        // eslint-disable-next-line
        manifest: require(_path.default.resolve(dllPath, `${key}-manifest.json`))
      }));
    });
  }

  const performance = {
    hints: false
  };
  return {
    mode,
    context,
    entry,
    output,
    module: _webpackServe.default,
    resolve,
    plugins,
    performance
  };
};

var _default = program => webpackConfig(program);

exports.default = _default;
module.exports = exports.default;