"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _fs = _interopRequireDefault(require("fs"));

var _path = _interopRequireDefault(require("path"));

var _ = require("..");

var _getExistConfigPath = _interopRequireDefault(require("../lib/get-exist-config-path"));

/**
 * webpack.serve.loader 配置文件
 * @author Joe Zhong <zhong.zhi@163.com>
 * @module config/webpack.serve.loader
 */
const context = (0, _.getContext)();
const babelOptions = {};

if (context && _fs.default.existsSync(_path.default.resolve(context, 'babel.config.js'))) {
  babelOptions.cwd = context;
}

const {
  assetExtensions,
  cssLoader: cssLoaderOptions,
  eslint: {
    enabled: eslintEnabled,
    options: eslintOptions
  }
} = (0, _.pRequire)('config/packing');
const postcssLoaderOptions = {
  // 兼容 eslint-loader@4.x
  postcssOptions: {
    config: (0, _getExistConfigPath.default)('postcss', context, __dirname)
  }
};
const jsLoaders = [{
  loader: 'babel-loader',
  options: babelOptions
}];

if (eslintEnabled) {
  jsLoaders.push({
    loader: 'eslint-loader',
    options: eslintOptions
  });
}

var _default = {
  rules: [{
    test: /\.(t|j)sx?$/i,
    exclude: /node_modules/,
    use: jsLoaders
  }, {
    test: /\.css$/i,
    use: [{
      loader: 'style-loader'
    }, {
      loader: 'css-loader',
      options: cssLoaderOptions
    }, {
      loader: 'postcss-loader',
      options: postcssLoaderOptions
    }]
  }, {
    test: /\.(scss|sass)$/i,
    use: [{
      loader: 'style-loader'
    }, {
      loader: 'css-loader',
      options: cssLoaderOptions
    }, {
      loader: 'postcss-loader',
      options: postcssLoaderOptions
    }, {
      loader: 'sass-loader'
    }]
  }, {
    test: /\.less$/i,
    use: [{
      loader: 'style-loader'
    }, {
      loader: 'css-loader',
      options: cssLoaderOptions
    }, {
      loader: 'postcss-loader',
      options: postcssLoaderOptions
    }, {
      loader: 'less-loader'
    }]
  }, {
    test: new RegExp(`.(${assetExtensions.join('|')})$`, 'i'),
    loader: 'file-loader',
    options: {
      name: '[path][name].[ext]',
      publicPath: '/'
    }
  }]
};
exports.default = _default;
module.exports = exports.default;