"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _fs = require("fs");

var _path = require("path");

var _util = require("util");

var _ = require("..");

var _getEntries = _interopRequireDefault(require("./get-entries"));

var _getEntryFromList = _interopRequireDefault(require("./get-entry-from-list"));

function injectTitle(html, templateEngine, title) {
  if (title) {
    // 为 SEO 准备的页面 meta 信息
    if (templateEngine === 'pug') {
      html = `${html}\nblock title\n  title ${title}\n`;
    } else {
      html = html.replace('__title__', title);
    }
  }

  return html;
}

function injectMeta(html, templateEngine, favicon, keywords, description) {
  if (templateEngine === 'pug') {
    const metaTags = [];

    if (keywords) {
      metaTags.push(`  meta(name="keywords" content="${keywords}")`);
    }

    if (description) {
      metaTags.push(`  meta(name="description" content="${description}")`);
    }

    if (favicon) {
      metaTags.push(`  link(rel="icon" type="image/png" href="${favicon}")`);
    }

    const metaHtml = metaTags.join('\n');

    if (metaHtml) {
      html = `${html}\nblock append meta\n${metaHtml}\n`;
    }
  } else {
    const metaTags = [];

    if (keywords) {
      metaTags.push(`  <meta name="keywords" content="${keywords}">`);
    }

    if (description) {
      metaTags.push(`  <meta name="description" content="${description}">`);
    }

    if (favicon) {
      metaTags.push(`  <link rel="icon" type="image/png" href="${favicon}">`);
    }

    const metaHtml = metaTags.join('\n');

    if (metaHtml) {
      html = html.replace('</head>', `${metaHtml}\n  </head>`);
    }
  }

  return html;
}

function injectManifestMeta(html, templateEngine, manifest) {
  if (templateEngine === 'pug') {
    return `${html}\nblock append meta\n  link(rel="manifest" href="/${manifest}")\n`;
  }

  return html.replace('</head>', `  <link rel="manifest" href="/${manifest}">\n  </head>`);
}

function injectStyles(html, templateEngine, chunkName, assets) {
  const publicPath = '/';
  const styles = assets.filter(({
    name
  }) => name.endsWith('.css'));

  if (styles.length > 0) {
    let styleHtml;

    if (templateEngine === 'pug') {
      styleHtml = `block append style\n${styles.map(({
        name
      }) => `  link(href="${publicPath + name}" rel="stylesheet")`).join('\n')}`;
      html = `${html}\n${styleHtml}\n`;
    } else {
      styleHtml = styles.map(({
        name
      }) => `  <link href="${publicPath + name}" rel="stylesheet">`).join('\n');
      html = html.replace('</head>', `${styleHtml}\n  </head>`);
    }
  }

  return html;
} // eslint-disable-next-line max-len


function injectScripts(html, templateEngine, chunkName, assets, commonChunks, scriptInjectPosition) {
  const publicPath = '/';
  const scripts = assets.filter(({
    name
  }) => name.endsWith('.js'));

  if ((0, _util.isObject)(commonChunks)) {
    Object.keys(commonChunks).forEach(name => {
      scripts.unshift({
        name: `${name}.js`
      });
    });
  }

  if (scripts.length > 0) {
    let scriptHtml;

    if (templateEngine === 'pug') {
      scriptHtml = `block append script\n${scripts.map(({
        name
      }) => `  script(src="${publicPath + name}")`).join('\n')}`;
      html = `${html}\n${scriptHtml}\n`;
    } else {
      scriptHtml = scripts.map(({
        name
      }) => `  <script src="${publicPath + name}"></script>`).join('\n');
      html = html.replace(`</${scriptInjectPosition}>`, `${scriptHtml}\n  </${scriptInjectPosition}>`);
    }
  }

  return html;
}

var _default = (app, appConfig) => {
  const context = (0, _.getContext)();
  const {
    path: {
      entries,
      src: {
        root: src,
        templates
      },
      mockPages
    },
    commonChunks,
    template: {
      options: {
        engine,
        extension,
        scriptInjectPosition,
        injectManifest,
        manifest,
        autoGeneration
      }
    },
    rewriteRules
  } = appConfig;
  const templatePages = templates.pages || templates; // 根据 entry 信息在 express 中添加路由

  const entryPoints = (0, _getEntries.default)(entries);
  Object.keys(entryPoints).forEach(chunkName => {
    app.get(`/${chunkName}`, (req, res, next) => {
      const entryFile = (0, _getEntryFromList.default)(chunkName, entryPoints[chunkName]);
      const settingsFile = (0, _path.resolve)(context, entryFile.replace(/(\.(t|j)s)/, '.settings$1'));
      let settings = {};

      if ((0, _fs.existsSync)(settingsFile)) {
        settings = (0, _.requireDefault)(settingsFile);
      }

      const {
        title,
        master,
        inject,
        favicon,
        keywords,
        description,
        ...templateData
      } = { ...appConfig.template.options,
        ...settings
      };
      const statsJson = res.locals.webpackStats.toJson({
        all: false,
        entrypoints: true
      });
      const {
        entrypoints
      } = statsJson.children ? statsJson.children[0] : statsJson;
      let html = '';
      const chunkNameMapTemplate = (0, _path.resolve)(context, src, `${templatePages}/${chunkName}${extension}`);
      const parent = (0, _path.isAbsolute)(master) ? master : (0, _path.resolve)(context, master);

      if (autoGeneration) {
        if ((0, _fs.existsSync)(parent)) {
          const templateString = (0, _fs.readFileSync)(parent, {
            encoding: 'utf-8'
          });
          html = templateString;
        } else {
          throw new Error(`找不到母模版：${parent}`);
        }
      } else if ((0, _fs.existsSync)(chunkNameMapTemplate)) {
        // 兼容 v3 以下版本
        const templateString = (0, _fs.readFileSync)(chunkNameMapTemplate, {
          encoding: 'utf-8'
        });
        html = templateString;
      } else {
        throw new Error(`找不网页模版：${parent}`);
      }

      const {
        assets
      } = entrypoints[chunkName];
      html = injectTitle(html, engine, title);
      html = injectMeta(html, engine, favicon, keywords, description);

      if (injectManifest) {
        html = injectManifestMeta(html, engine, manifest);
      }

      if (inject && assets.length > 0) {
        html = injectStyles(html, engine, chunkName, assets);
        html = injectScripts(html, engine, chunkName, assets, commonChunks, scriptInjectPosition);
      }

      html = html // 替换格式为 __var__ 用户自定义变量
      .replace(/__(\w+)__/gm, (re, $1) => templateData[$1] || '');

      if (engine === 'html') {
        res.send(html);
      } else {
        // 将模版内容传递到下一个中间件处理
        res.filename = parent;
        res.basedir = (0, _path.dirname)((0, _path.resolve)(context, src, templatePages));
        res.template = html;
        next();
      }
    });

    if (engine !== 'html') {
      const parser = require(`packing-template-${engine}`);

      app.get(`/${chunkName}`, parser({
        mockData: mockPages,
        // templates: dirname(templatePages),
        rewriteRules
      }));
    }
  });
};

exports.default = _default;
module.exports = exports.default;